@@ -27,7 +27,7 @@ mod test {
     use tokio::fs;
     use std::os::windows::io::AsRawHandle;
 
-    use crate::{lock_contended_error, tokio::AsyncFileExt, FsStats};
+    use crate::{lock_contended_error, tokio::AsyncFileExt};
 
     /// The duplicate method returns a file with a new file handle.
     #[tokio::test]
